@@ -1,5 +1,5 @@
 from typing import Tuple, Generic, List, NoReturn, final
-import towpy.config
+from towpy import config
 from pygame import *
 
 
